pub enum ConvertToJsonError<'a> {
Value(&'a Value),
DurationOverflow(&'a Duration),
}Variants
Value(&'a Value)
We cannot convert the CEL value to JSON. Some CEL types (like functions) are not representable in JSON.
DurationOverflow(&'a Duration)
The duration is too large to convert to nanoseconds. Any duration of 2^63 nanoseconds or more will overflow. We’ll return the duration type in the error message.